@@ -5,8 +5,9 @@ from flask.ext.assets import Environment, Bundle
 from flask_debugtoolbar import DebugToolbarExtension
 from markdown import markdown
 
+from . import __version__
 from config import CONFIG as cfg
-from db import REDIS
+import db
 from models import Experiment
 import utils
 
@@ -21,7 +22,7 @@ js = Bundle('js/jquery.js', 'js/d3.js',
             output="{0}/sixpack.js".format(cfg.get('asset_path', 'gen')))
 
 css = Bundle('css/bootstrap.css',
-             'css/bootstrap-responsive.css', 'css/style.css',
+             'css/bootstrap-responsive.css', 'css/sixpack.css',
              filters=['yui_css'],
              output="{0}/sixpack.css".format(cfg.get('asset_path', 'gen')))
 
@@ -30,29 +31,43 @@ assets.register('js_all', js)
 assets.register('css_all', css)
 
 
-# List of experiments
+@app.route('/_status')
+@utils.service_unavailable_on_connection_error
+def status():
+    db.REDIS.ping()
+    return utils.json_success({'version': __version__}, request)
+
+
 @app.route("/")
 def hello():
-    experiments = Experiment.all_names(REDIS)
-    return render_template('dashboard.html', experiments=experiments)
+    experiments = Experiment.all(db.REDIS)
+    experiments = [exp.name for exp in experiments]
+    return render_template('dashboard.html', experiments=experiments, page='home')
+
+
+@app.route('/archived')
+def archived():
+    experiments = Experiment.all(db.REDIS, False)
+    experiments = [exp.name for exp in experiments if exp.is_archived()]
+    return render_template('dashboard.html', experiments=experiments, page='archived')
 
 
 @app.route('/experiments.json')
 def experiment_list():
-    experiments = Experiment.all(REDIS)
+    experiments = Experiment.all(db.REDIS)
     period = determine_period()
     experiments = [simple_markdown(exp.objectify_by_period(period)) for exp in experiments]
     return jsonify({'experiments': experiments})
 
 
 # Details for experiment
-@app.route("/experiment/<experiment_name>/")
+@app.route("/experiments/<experiment_name>/")
 def details(experiment_name):
     experiment = find_or_404(experiment_name)
     return render_template('details.html', experiment=experiment)
 
 
-@app.route("/experiment/<experiment_name>.json")
+@app.route("/experiments/<experiment_name>.json")
 def json_details(experiment_name):
     experiment = find_or_404(experiment_name)
     period = determine_period()
@@ -60,7 +75,7 @@ def json_details(experiment_name):
     return jsonify(obj)
 
 
-@app.route("/experiment/<experiment_name>/export", methods=['POST'])
+@app.route("/experiments/<experiment_name>/export", methods=['POST'])
 def export(experiment_name):
     experiment = find_or_404(experiment_name)
 
@@ -74,7 +89,7 @@ def export(experiment_name):
 
 
 # Set winner for an experiment
-@app.route("/experiment/<experiment_name>/winner/", methods=['POST'])
+@app.route("/experiments/<experiment_name>/winner/", methods=['POST'])
 def set_winner(experiment_name):
     experiment = find_or_404(experiment_name)
     experiment.set_winner(request.form['alternative_name'])
@@ -83,7 +98,7 @@ def set_winner(experiment_name):
 
 
 # Reset experiment
-@app.route("/experiment/<experiment_name>/reset/", methods=['POST'])
+@app.route("/experiments/<experiment_name>/reset/", methods=['POST'])
 def reset_experiment(experiment_name):
     experiment = find_or_404(experiment_name)
     experiment.reset()
@@ -92,7 +107,7 @@ def reset_experiment(experiment_name):
 
 
 # Reset experiment winner
-@app.route("/experiment/<experiment_name>/winner/reset/", methods=['POST'])
+@app.route("/experiments/<experiment_name>/winner/reset/", methods=['POST'])
 def reset_winner(experiment_name):
     experiment = find_or_404(experiment_name)
     experiment.reset_winner()
@@ -101,7 +116,7 @@ def reset_winner(experiment_name):
 
 
 # Delete experiment
-@app.route("/experiment/<experiment_name>/delete/", methods=['POST'])
+@app.route("/experiments/<experiment_name>/delete/", methods=['POST'])
 def delete_experiment(experiment_name):
     experiment = find_or_404(experiment_name)
     experiment.delete()
@@ -110,7 +125,7 @@ def delete_experiment(experiment_name):
 
 
 # Archive experiment
-@app.route("/experiment/<experiment_name>/archive", methods=['POST'])
+@app.route("/experiments/<experiment_name>/archive", methods=['POST'])
 def toggle_experiment_archive(experiment_name):
     experiment = find_or_404(experiment_name)
     if experiment.is_archived():
@@ -121,7 +136,7 @@ def toggle_experiment_archive(experiment_name):
     return redirect(url_for('details', experiment_name=experiment.name))
 
 
-@app.route("/experiment/<experiment_name>/description", methods=['POST'])
+@app.route("/experiments/<experiment_name>/description", methods=['POST'])
 def update_experiment_description(experiment_name):
     experiment = find_or_404(experiment_name)
 
@@ -147,7 +162,10 @@ def internal_server_error(e):
 
 def find_or_404(experiment_name):
     try:
-        return Experiment.find(experiment_name, REDIS)
+        exp = Experiment.find(experiment_name, db.REDIS)
+        if request.args.get('kpi'):
+            exp.set_kpi(request.args.get('kpi'))
+        return exp
     except:
         abort(404)
 
